<?php
/*
	Plugin Name: ELEX USPS Shipping Method for WooCommerce
	Plugin URI: https://elextensions.com/plugin/woocommerce-usps-shipping-plugin-with-print-label/
	Description: Obtain real time Shipping Rates via the USPS Shipping API.
	Version: 1.4.9
	Author: ELEXtensions
	WC requires at least: 2.6
	WC tested up to: 7.1
	Author URI: https://elextensions.com/
	https://www.usps.com/webtools/htm/Rate-Calculators-v1-5.htm
	https://www.usps.com/business/web-tools-apis/delivery-confirmation-domestic-shipping-label-api.htm
*/

if ( ! defined( 'ELEX_USPS_SHIPPING_BASIC_PLUGIN_DIR_PATH' ) ) {
	define( 'ELEX_USPS_SHIPPING_BASIC_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'ELEX_USPS_SHIPPING_BASIC_PLUGIN_DIR_URL' ) ) {
	define( 'ELEX_USPS_SHIPPING_BASIC_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );
}
function elex_usps_basic_pre_activation_check() {
	if ( is_plugin_active( 'usps-woocommerce-shipping/usps-woocommerce-shipping.php' ) ) {
		deactivate_plugins( basename( __FILE__ ) );
		wp_die( esc_html_e( "Is everything fine? You already have the Premium version installed in your website. For any issues, kindly raise a ticket via <a target='_blank' href='https://elextensions.com/support/'>Elex Support</a>", 'wf-usps-woocommerce-shipping' ), '', array( 'back_link' => 1 ) );
	}
}

register_activation_hook( __FILE__, 'elex_usps_basic_pre_activation_check' );
if ( ! defined( 'ELEX_USPS_ID' ) ) {
	define( 'ELEX_USPS_ID', 'wf_shipping_usps' );
}

/**
 * Check if WooCommerce is active
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) || ( is_multisite() && is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) ) {

	/**
	 * WC_USPS class
	 */
	if ( ! class_exists( 'ELEX_USPS_WooCommerce_Shipping' ) ) { 
		class ELEX_USPS_WooCommerce_Shipping {
			/**
			 * Constructor
			 */
			public function __construct() {
				add_action( 'init', array( $this, 'init' ) );
				add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
				add_action( 'woocommerce_shipping_init', array( $this, 'shipping_init' ) );
				add_filter( 'woocommerce_shipping_methods', array( $this, 'add_method' ) );
				add_action( 'admin_enqueue_scripts', array( $this, 'scripts' ) );
			}

			/**
			 * Localisation
			 */
			
			public function init() {
				if ( ! class_exists( 'ELEX_Order' ) ) {
					include_once 'includes/class-wf-legacy.php';
				}       
			}


			/**
			 * Plugin page links
			 */
			public function plugin_action_links( $links ) {
				$plugin_links = array(
					'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=shipping&section=elex_shipping_usps' ) . '">' . __( 'Settings', 'wf-usps-woocommerce-shipping' ) . '</a>',

					'<a href="https://elextensions.com/plugin/woocommerce-usps-shipping-plugin-with-print-label/" target="_blank">' . __( 'Premium Upgrade', 'wf-usps-woocommerce-shipping' ) . '</a>',

					'<a href="https://elextensions.com/support/" target="_blank">' . __( 'Support', 'wf-usps-woocommerce-shipping' ) . '</a>',
				);
				return array_merge( $plugin_links, $links );
			}

			/**
			 * Load gateway class
			 */
			public function shipping_init() {
				include_once  'includes/class-elex-shipping-usps.php' ;
			}

			/**
			 * Add method to WC
			 */
			public function add_method( $methods ) {
				$methods[] = 'ELEX_Shipping_USPS';
				return $methods;
			}

			/**
			 * Enqueue scripts
			 */
			public function scripts() {
				wp_enqueue_script( 'jquery' );
				wp_enqueue_script( 'jquery-ui-sortable' );
				wp_enqueue_script( 'common-script', plugins_url( '/resources/js/wf_common.js', __FILE__ ), array( 'jquery' ), '1.0' );
				wp_enqueue_style( 'wf-common-style', plugins_url( '/resources/css/wf_common_style.css', __FILE__ ), array(), '1.0' );
			}
		}
		new ELEX_USPS_WooCommerce_Shipping();
	}
}
